@@ -8,4 +8,4 @@ kbd_mode '-u' < '/dev/tty1'
 kbd_mode '-u' < '/dev/tty2' 
 kbd_mode '-u' < '/dev/tty3' 
 kbd_mode '-u' < '/dev/tty4' 
-loadkeys '/tmp/tmpkbd.WMb8KN' > '/dev/null' 
+loadkeys '/tmp/tmpkbd.kSM5qD' > '/dev/null' 
